@@ -3,7 +3,11 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
+import importlib.metadata
+
 import parameterspace.priors
 import parameterspace.transformations
 from parameterspace.parameters import *
 from parameterspace.parameterspace import *
+
+__version__ = importlib.metadata.version("parameterspace")
