@@ -26,7 +26,7 @@ class ContinuousParameter(BaseParameter):
         *,
         prior: Optional[BasePrior] = None,
         transformation: Union[BaseTransformation, str, None] = None,
-        inactive_numerical_value: Optional[float] = np.nan
+        inactive_numerical_value: Optional[float] = np.nan,
     ):
         """
         Initialize with options for continuous parameter.
@@ -36,11 +36,15 @@ class ContinuousParameter(BaseParameter):
             bounds: Lower and upper bound for the parameter.
             prior: Default prior is the Uniform prior which will fail if at least one
                 of the bounds is infinite!
-            transformation: Default transformation is the identity. If a string is
-                given, the transform is created automatically for supported transforms.
+            transformation: Default transformation is the affine-linear transformation
+                of the bounds to `[0,1]`. If a string is given, the transform is created
+                automatically for supported transforms.
             inactive_numerical_value:  Placeholder value for this parameter in case
                 it is not active.
         """
+        if not np.isfinite(bounds).all():
+            raise ValueError(f"Bounds need to be finite, but are {bounds}")
+
         self.bounds = np.array(bounds)
 
         if not isinstance(transformation, BaseTransformation):
@@ -63,7 +67,7 @@ class ContinuousParameter(BaseParameter):
     def __repr__(self):
         """Add bounds to the string representation."""
         string = super().__repr__()
-        string += "Bounds: [{}, {}]\n".format(*self.bounds)
+        string += f"Bounds: ({self.bounds[0]}, {self.bounds[1]})\n"
         return string
 
     def check_value(self, value):
