@@ -4,6 +4,7 @@
 # SPDX-License-Identifier: Apache-2.0
 
 # For type hinting custom class (ParameterSpace):
+
 from __future__ import annotations
 
 import copy
@@ -12,12 +13,17 @@ from typing import Any, Callable, List, Optional, Tuple, Union
 
 import numpy as np
 
-import parameterspace as ps
 from parameterspace.base import SearchSpace
 from parameterspace.condition import Condition
+from parameterspace.parameters import (
+    CategoricalParameter,
+    ContinuousParameter,
+    IntegerParameter,
+)
 from parameterspace.parameters.base import BaseParameter
 
 
+# pylint: disable=too-many-public-methods
 class ParameterSpace(SearchSpace):
     """Class representing a parameter space that allows to sampling, converting and
     checking configurations.
@@ -39,7 +45,7 @@ class ParameterSpace(SearchSpace):
         return self._parameters[name]
 
     def __repr__(self):
-        string = "ParameterSpace with the following parameteres and conditions\n"
+        string = "ParameterSpace with the following parameters and conditions\n"
         for p in self._parameters.values():
             string += str(p["parameter"])
             string += str(p["condition"]) + "\n"
@@ -101,7 +107,7 @@ class ParameterSpace(SearchSpace):
                 self.add(p["parameter"], tmp_condition)
         else:
             if parameter.name in self._parameters:
-                raise ValueError("Parameter %s already exists!" % parameter.name)
+                raise ValueError(f"Parameter {parameter.name} already exists!")
             self._parameters[parameter.name] = {
                 "parameter": parameter,
                 "condition": condition,
@@ -188,10 +194,10 @@ class ParameterSpace(SearchSpace):
             if not self._parameters[name]["parameter"].check_value(value):
                 raise ValueError(f"Invalid value `{value}` for parameter '{name}'!")
 
-        # remove any constants here that might not be active based on some parameter values,
-        # but are still specified here.
+        # remove any constants here that might not be active based on some parameter
+        # values, but are still specified here.
         actual_constants = copy.copy(kwargs)
-        for n in kwargs.keys():
+        for n in kwargs:
             p = self._parameters[n]
             if p["condition"].all_varnames <= set(kwargs) and not p["condition"](
                 kwargs
@@ -288,18 +294,17 @@ class ParameterSpace(SearchSpace):
         """Sample a random configuration based on the priors.
 
         Args:
-            partial_configuration: Partial assignment of certain variables. If
-                not `None`, only the remaining variables are set randomly. All
-                conditions are honored.\n
-                Right now, there is no check if the partitial configuration
-                violates any conditions.
-            rng: A Numpy random number generator used to generate the
-                sample. Overrides the internal random number generator that is
-                set on initialization of the space.
+            partial_configuration: Partial assignment of certain variables. If not
+                `None`, only the remaining variables are set randomly. All conditions
+                are honored.
+                Right now, there is no check if the partial configuration violates any
+                conditions.
+            rng: A Numpy random number generator used to generate the sample. Overrides
+                the internal random number generator that is set on initialization of
+                the space.
 
         Raises:
-            ValueError: If a passed value is not valid for the corresponding
-                parameter.
+            ValueError: If a passed value is not valid for the corresponding parameter.
 
         Returns:
             Random parameter configuration.
@@ -310,7 +315,7 @@ class ParameterSpace(SearchSpace):
         config = {} if partial_configuration is None else partial_configuration
         for n, v in config.items():
             if not self._parameters[n]["parameter"].check_value(v):
-                raise ValueError("%s = %s is not valid for this space" % (n, v))
+                raise ValueError(f"{n} = {v} is not valid for this space")
 
         config.update(self._constants)
 
@@ -363,7 +368,7 @@ class ParameterSpace(SearchSpace):
     def check_validity(self, configuration: dict) -> bool:
         """Test whether the provided configuration is complete and valid.
 
-        It checks wheter all parameters have a valid value or are not active.
+        It checks whether all parameters have a valid value or are not active.
         A warning is shown describing the issue.
 
         Args:
@@ -401,8 +406,8 @@ class ParameterSpace(SearchSpace):
         return True
 
     def remove_inactive(self, configuration: dict) -> dict:
-        """Identify and remove parameters that should not have a value because
-        their condition is unsatisfied.
+        """Identify and remove parameters that should not have a value because their
+        condition is unsatisfied.
 
         Args:
             configuration: Configuration to check.
@@ -421,7 +426,7 @@ class ParameterSpace(SearchSpace):
         for name, value in self._constants.items():
             if name not in configuration:
                 raise ValueError(
-                    f"Configuration does not contain contant `{name} == {value}`!"
+                    f"Configuration does not contain constant `{name} == {value}`!"
                 )
             if configuration[name] != value:
                 raise ValueError(
@@ -435,29 +440,6 @@ class ParameterSpace(SearchSpace):
             vec[i] = p["parameter"].val2num(v)
         return vec
 
-    def val2num(self, configuration: dict) -> np.ndarray:
-        """
-        Attention:
-            Deprecated. Use [ParameterSpace.to_numerical]\
-            [parameterspace.parameterspace.ParameterSpace.to_numerical].
-
-        Args:
-            configuration: Configuration to convert.
-
-        Raises:
-            ValueError:  If configuration contains invalid names or values.
-
-        Returns:
-            Vector representation of the configuration.
-
-        """
-        warnings.warn(
-            "Method ParameterSpace.val2num is deprecated and will be removed in "
-            + "the future! Please use ParameterSpace.to_numerical instead.",
-            category=DeprecationWarning,
-        )
-        return self.to_numerical(configuration)
-
     def from_numerical(self, vector: np.ndarray) -> dict:
         conf = {}
         for i, (n, p) in enumerate(self._parameters.items()):
@@ -466,26 +448,6 @@ class ParameterSpace(SearchSpace):
         conf.update(self._constants)
         return self.remove_inactive(conf)
 
-    def num2val(self, vector: np.ndarray) -> dict:
-        """
-        Attention:
-            Deprecated. Use [ParameterSpace.from_numerical]\
-            [parameterspace.parameterspace.ParameterSpace.from_numerical].
-
-        Args:
-            vector: Numerical vector representation of a configuration.
-
-        Returns:
-            Dictionary representation of the input configuration.
-
-        """
-        warnings.warn(
-            "Method ParameterSpace.num2val is deprecated and will be removed in the "
-            + "future! Please use ParameterSpace.from_numerical instead.",
-            category=DeprecationWarning,
-        )
-        return self.from_numerical(vector)
-
     def has_conditions(self) -> bool:
         """Check if any of the parameters in the current `ParameterSpace` is
         conditioned on others.
@@ -499,7 +461,7 @@ class ParameterSpace(SearchSpace):
         return False
 
     def get_continuous_bounds(self) -> List[Tuple]:
-        """Return the ParamerSpace specific bounds if it is purely continuous.
+        """Return the ParameterSpace specific bounds if it is purely continuous.
 
         Raises:
             ValueError: If `ParameterSpace` contains non-continuous parameters.
@@ -512,7 +474,7 @@ class ParameterSpace(SearchSpace):
             p = self[n]["parameter"]
             if not p.is_continuous:
                 raise ValueError(
-                    "Parameterspace contains non-continuous parameter:\n{}".format(p)
+                    f"Parameterspace contains a non-continuous parameter:\n{p}"
                 )
             bounds.append(tuple(p.get_numerical_bounds()))
         return bounds
@@ -526,11 +488,14 @@ class ParameterSpace(SearchSpace):
                 to be rendered in LaTeX table.
 
         Returns:
-            LaTeX table represenation
+            LaTeX table representation
         """
         try:
+            # pylint: disable=import-outside-toplevel
             from num2tex import configure as num2tex_configure
             from num2tex import num2tex
+
+            # pylint: enable=import-outside-toplevel
         except ImportError as e:
             raise RuntimeError(
                 "To use this functionality, please install num2tex."
@@ -547,42 +512,39 @@ class ParameterSpace(SearchSpace):
             "\\hline",
         ]
 
-        for parameter_name in self._parameters:
-            parameter = self._parameters[parameter_name]["parameter"]
+        for parameter_name, parameter_value in self._parameters.items():
+            parameter = parameter_value["parameter"]
 
             name_str = name_dict.get(parameter_name, parameter.name)
             transformation_name = type(parameter._transformation).__name__
             prior_name = type(parameter._prior).__name__
 
-            if isinstance(parameter, ps.IntegerParameter):
+            if isinstance(parameter, IntegerParameter):
                 type_str = "Integer"
-                values_str = "$[{0[0]}, {0[1]}]$".format(parameter.bounds)
+                values_str = f"$[{parameter.bounds[0]}, {parameter.bounds[1]}]$"
                 transformation_str = "Log" if "Log" in transformation_name else ""
                 prior_str = prior_name
 
-            if isinstance(parameter, ps.ContinuousParameter):
+            if isinstance(parameter, ContinuousParameter):
                 type_str = "Float"
                 prior_str = prior_name
 
                 if "Log" in transformation_name:
                     transformation_str = "Log"
-                    values_str = "$[{}, {}]$".format(
-                        num2tex(parameter.bounds[0], precision=2),
-                        num2tex(parameter.bounds[1], precision=2),
-                    )
+                    lower_bound = num2tex(parameter.bounds[0], precision=2)
+                    upper_bound = num2tex(parameter.bounds[1], precision=2)
+                    values_str = f"$[{lower_bound}, {upper_bound}]$"
                 else:
                     transformation_str = " "
-                    values_str = "$[{0[0]}, {0[1]}]$".format(parameter.bounds)
+                    values_str = f"$[{parameter.bounds[0]}, {parameter.bounds[1]}]$"
 
-            if isinstance(parameter, ps.CategoricalParameter):
+            if isinstance(parameter, CategoricalParameter):
                 type_str = "Categorical"
                 values_str = "[" + ", ".join(parameter.values) + "]"
                 transformation_str = " "
                 prior_probs = parameter._prior.probabilities
                 prior_str = (
-                    "["
-                    + ",".join(map(lambda p: "{:3.2f}".format(p), prior_probs))
-                    + "]"
+                    "[" + ",".join(map(lambda p: f"{p:3.2f}", prior_probs)) + "]"
                 )
 
             latex_strs.append(
